@@ -40,7 +40,7 @@ our @EXPORT    = qw(system_identity suite_run calc_scalability);
 our $datadir   = dist_dir("Benchmark-DKbench");
 my $mono_clock = $^O !~ /win/i || $Time::HiRes::VERSION >= 1.9764;
 
-our $VERSION = '2.3';
+our $VERSION = '2.4';
 
 =head1 NAME
 
@@ -72,6 +72,12 @@ scenario.
 
 =head1 INSTALLATION
 
+See the L</"setup_dkbench"> script below for more on the installation of a couple
+of optional benchmarks and standardizing your benchmarking environment, otherwise
+here are some general guidelines for verious systems.
+
+=head2 Linux / WSL etc
+
 The only non-CPAN software required to install/run the suite is a build environment
 for the C/XS modules (C compiler, make etc.) and Perl. On the most popular Linux
 package managers you can easily set up such an environment (as root or with sudo):
@@ -89,10 +95,13 @@ root/sudo is the easiest, will install for all users):
 
  cpanm -n Benchmark::DKbench
 
-See the C<setup_dkbench> script below for more on the installation of a couple of
-optional benchmarks and standardizing your benchmarking environment.
+=head2 Solaris
 
-=head3 Strawberry Perl
+You will need to install the Oracle Solaris Studio development package to have a
+compiler environment, and to add its C<bin> directory to your PATH, before installing
+the benchmark suite.
+
+=head2 Strawberry Perl
 
 If you are on Windows, you should be using the Windows Subsystem for Linux (WSL)
 for running Perl or, if you can't (e.g. old Windows verions), cygwin instead.
@@ -102,10 +111,10 @@ with L<App::cpanminus> (most Strawberry Perl verions have it installed):
 
  cpanm -n Benchmark::DKbench
 
-otherwise with the base CPAN shell: 
+otherwise with the base CPAN shell:
 
  perl -MCPAN -e shell
- 
+
  > notest install Benchmark::DKbench
 
 and then note that the scripts get the batch extension appended, so C<dkbench.bat>
@@ -134,11 +143,13 @@ options to control number of threads, iterations, which benchmarks to run etc:
  --multi,       -m     : Multi-threaded using all your CPU cores/threads.
  --max_threads <i>     : Override the cpu detection to specify max cpu threads.
  --iter <i>,    -i <i> : Number of suite iterations (with min/max/avg at the end).
+ --stdev               : Show relative standard deviation (for iter > 1).
  --include <regex>     : Run only benchmarks that match regex.
  --exclude <regex>     : Do not run benchmarks that match regex.
  --time,        -t     : Report time (sec) instead of score.
  --quick,       -q     : Quick benchmark run (implies -t).
  --no_mce              : Do not run under MCE::Loop (implies -j 1).
+ --scale <i>,   -s <i> : Scale the bench workload by x times (incompatible with -q).
  --skip_bio            : Skip BioPerl benchmarks.
  --skip_prove          : Skip Moose prove benchmark.
  --time_piece          : Run optional Time::Piece benchmark (see benchmark details).
@@ -156,25 +167,33 @@ multi vs single threaded scalability.
 The scores are calibrated such that a reference CPU (Intel Xeon Platinum 8481C -
 Sapphire Rapids) would achieve a score of 1000 in a single-core benchmark run using
 the default software configuration (Linux/Perl 5.36.0 built with multiplicity and
-threads, with reference CPAN module versions).
+threads, with reference CPAN module versions). Perl built without thread support and
+multi(plicity) will be a bit faster (usually in the order of ~3-4%), while older Perl
+versions will most likely be slower. Different CPAN module versions will also impact
+scores, using C<setup_dkbench> is a way to ensure a reference environment for more
+meaningful hardware comparisons.
 
-The multi-thread scalability should approach 100% if each thread runs on a full core
-(i.e. no SMT), and the core can maintain the clock speed it had on the single-thread
-runs. Note that the overall scalability is an average of the benchmarks that drops
-non-scaling outliers (over 2*stdev less than the mean).
+The multi-thread scalability calculated by the suite should approach 100% if each
+thread runs on a full core (i.e. no SMT), and the core can maintain the clock speed
+it had on the single-thread runs. Note that the overall scalability is an average
+of the benchmarks that drops non-scaling outliers (over 2*stdev less than the mean).
+
+If you want to reduce the effects of thermal throttling, which will lower the speed
+of (mainly multi-threaded) benchmarks as the CPU temperature increases, the C<sleep>
+option can help by adding cooldown time between each benchmark.
 
 The suite will report a Pass/Fail per benchmark. A failure may be caused if you have
 different CPAN module version installed - this is normal, and you will be warned.
 
-The suite uses L<MCE::Loop> to run on the desired number of parallel threads, although
-there is an option to disable it, which forces a single-thread run.
+L<MCE::Loop> is used to run on the desired number of parallel threads, with minimal
+overhead., There is an option to disable it, which forces a single-thread run.
 
 =head2 C<setup_dkbench>
 
 Simple installer to check/get the reference versions of CPAN modules and download
 the Genbank data file required for the BioPerl benchmarks of the DKbench suite.
 
-It assumes that you have some software already installed (see INSTALLATION above),
+It assumes that you have some software already installed (see L</"INSTALLATION"> above),
 try C<setup_dkbench --help> will give you more details.
 
  setup_dkbench [--force --sudo --test --data=s --help]
@@ -297,6 +316,9 @@ Prints out software/hardware configuration and returns then number of cores dete
 Runs the benchmark suite given the C<%options> and prints results. Returns a hash
 with run stats.
 
+The options accepted are the same as the C<dkbench> script (in their long form),
+except C<help>, C<setup> and C<max_threads> which are command-line only.
+
 =head2 C<calc_scalability>
 
  calc_scalability(\%options, \%stat_single, \%stat_multi);
@@ -322,7 +344,7 @@ actual workload.
 =head2 SCORES
 
 Some sample DKbench score results from various systems for comparison (all on
-reference setup with Perl 5.36.0):
+reference setup with Perl 5.36.0 thread-multi):
 
  CPU                                     Cores/HT   Single   Multi   Scalability
  Intel i7-4750HQ @ 2.0 (MacOS)                4/8     612     2332      46.9%
@@ -414,7 +436,7 @@ sub suite_run {
     my $opt = shift;
     $datadir = $opt->{datapath} if $opt->{datapath};
     $opt->{threads} //= 1;
-    $opt->{repeat} //= 1;
+    $opt->{scale} //= 1;
     $opt->{f} = $opt->{time} ? '%.3f' : '%5.0f';
     my %stats = (threads => $opt->{threads});
 
@@ -455,7 +477,14 @@ sub calc_scalability {
     print (("-"x40)."\n");
     my $avg1 = min_max_avg($stats1->{total}->{$display});
     my $avg2 = min_max_avg($stats2->{total}->{$display});
-    print "DKbench summary ($cnt benchmarks, $stats2->{threads} threads):\n";
+    print "DKbench summary ($cnt benchmark";
+    print "s" if $cnt > 1;
+    print " x$opt->{scale} scale" if $opt->{scale} && $opt->{scale} > 1;
+    print ", $opt->{iter} iterations" if $opt->{iter} && $opt->{iter} > 1;
+    print ", $stats2->{threads} thread";
+    print "s" if $stats2->{threads} > 1;
+    print "):\n";
+    $opt->{f} .= "s" if $opt->{time};
     print pad_to("Single:").sprintf($opt->{f}, $avg1)."\n";
     print pad_to("Multi:").sprintf($opt->{f}, $avg2)."\n";
     my @newperf = Benchmark::DKbench::drop_outliers(\@perf, -1);
@@ -520,7 +549,7 @@ sub mce_bench_run {
             MCE->gather([$time, $res]);
         }
     }
-    (1 .. $opt->{threads} * $opt->{repeat});
+    (1 .. $opt->{threads} * $opt->{scale});
 
     my ($res, $time) = ('Pass', 0);
     foreach (@stats) {
@@ -528,7 +557,7 @@ sub mce_bench_run {
         $res = $_->[1] if $_->[1] ne 'Pass';
     }
 
-    return $time/($opt->{threads}*$opt->{repeat} || 1), $res;
+    return $time/($opt->{threads}*$opt->{scale} || 1), $res;
 }
 
 sub bench_run {
@@ -1023,7 +1052,8 @@ sub total_stats {
     my $benchmarks = benchmark_list();
     my $display = $opt->{time} ? 'times' : 'scores';
     my $title   = $opt->{time} ? 'Time (sec)' : 'Score';
-    print "Aggregates:\n".pad_to("Benchmark",24).pad_to("Avg $title").pad_to("Min $title").pad_to("Max $title");
+    print "Aggregates ($opt->{iter} iterations):\n".pad_to("Benchmark",24).pad_to("Avg $title").pad_to("Min $title").pad_to("Max $title");
+    print pad_to("stdev %") if $opt->{stdev};
     print pad_to("Pass %") unless $opt->{time};
     print "\n";
     foreach my $bench (sort keys %$benchmarks) {
@@ -1044,7 +1074,13 @@ sub calc_stats {
     my $arr = shift;
     my $pad = shift;
     my ($min, $max, $avg) = min_max_avg($arr);
-    return $avg, join '', map {pad_to(sprintf($opt->{f}, $_), $pad)} ($avg,$min,$max);
+    my $str = join '', map {pad_to(sprintf($opt->{f}, $_), $pad)} ($avg,$min,$max);
+    if ($opt->{stdev} && $avg) {
+        my $stdev = avg_stdev($arr);
+        $stdev *= 100/$avg;
+        $str .= pad_to(sprintf("%0.2f%%", $stdev), $pad);
+    }
+    return $avg, $str;
 }
 
 sub min_max_avg {
